@@ -40,6 +40,14 @@ const sfBlendMode sfBlendAdd = { sfBlendFactorSrcAlpha, sfBlendFactorOne, sfBlen
 const sfBlendMode sfBlendMultiply = { sfBlendFactorDstColor, sfBlendFactorZero, sfBlendEquationAdd,
                                       sfBlendFactorDstColor, sfBlendFactorZero, sfBlendEquationAdd };
 
+////////////////////////////////////////////////////////////
+const sfBlendMode sfBlendMin = { sfBlendFactorOne, sfBlendFactorOne, sfBlendEquationMin,
+                                 sfBlendFactorOne, sfBlendFactorOne, sfBlendEquationMin };
+
+////////////////////////////////////////////////////////////
+const sfBlendMode sfBlendMax = { sfBlendFactorOne, sfBlendFactorOne, sfBlendEquationMax,
+                                 sfBlendFactorOne, sfBlendFactorOne, sfBlendEquationMax };
+
 ////////////////////////////////////////////////////////////
 const sfBlendMode sfBlendNone = { sfBlendFactorOne, sfBlendFactorZero, sfBlendEquationAdd,
-                                      sfBlendFactorOne, sfBlendFactorZero, sfBlendEquationAdd };
+                                  sfBlendFactorOne, sfBlendFactorZero, sfBlendEquationAdd };
