@@ -66,10 +66,10 @@ sfColor sfColor_fromRGBA(sfUint8 red, sfUint8 green, sfUint8 blue, sfUint8 alpha
 ////////////////////////////////////////////////////////////
 sfColor sfColor_fromInteger(sfUint32 color)
 {
-    sfUint8 red =   (color & 0xff000000) >> 24;
-    sfUint8 green = (color & 0x00ff0000) >> 16;
-    sfUint8 blue =  (color & 0x0000ff00) >> 8;
-    sfUint8 alpha = (color & 0x000000ff) >> 0;
+    sfUint8 red =   static_cast<sfUint8>((color & 0xff000000) >> 24);
+    sfUint8 green = static_cast<sfUint8>((color & 0x00ff0000) >> 16);
+    sfUint8 blue =  static_cast<sfUint8>((color & 0x0000ff00) >> 8);
+    sfUint8 alpha = static_cast<sfUint8>((color & 0x000000ff) >> 0);
 
     return sfColor_fromRGBA(red, green, blue, alpha);
 }
@@ -78,7 +78,7 @@ sfColor sfColor_fromInteger(sfUint32 color)
 ////////////////////////////////////////////////////////////
 sfUint32 sfColor_toInteger(sfColor color)
 {
-    return (color.r << 24) | (color.g << 16) | (color.b << 8) | color.a;
+    return static_cast<sfUint32>((color.r << 24) | (color.g << 16) | (color.b << 8) | color.a);
 }
 
 
