@@ -121,6 +121,13 @@ float sfFont_getKerning(const sfFont* font, sfUint32 first, sfUint32 second, uns
 }
 
 
+////////////////////////////////////////////////////////////
+float sfFont_getBoldKerning(const sfFont* font, sfUint32 first, sfUint32 second, unsigned int characterSize)
+{
+    CSFML_CALL_RETURN(font, getKerning(first, second, characterSize, true), 0);
+}
+
+
 ////////////////////////////////////////////////////////////
 float sfFont_getLineSpacing(const sfFont* font, unsigned int characterSize)
 {
@@ -152,6 +159,26 @@ const sfTexture* sfFont_getTexture(sfFont* font, unsigned int characterSize)
     return &font->Textures[characterSize];
 }
 
+
+////////////////////////////////////////////////////////////
+void sfFont_setSmooth(sfFont* font, sfBool smooth)
+{
+    font->This.setSmooth(smooth == sfTrue);
+}
+
+
+////////////////////////////////////////////////////////////
+sfBool sfFont_isSmooth(const sfFont *font)
+{
+    if (font->This.isSmooth())
+    {
+        return sfTrue;
+    }
+
+    return sfFalse;
+}
+
+
 ////////////////////////////////////////////////////////////
 sfFontInfo sfFont_getInfo(const sfFont* font)
 {
