@@ -27,9 +27,11 @@
 ////////////////////////////////////////////////////////////
 #include <SFML/Graphics/Image.h>
 #include <SFML/Graphics/ImageStruct.h>
+#include <SFML/System/BufferStruct.h>
 #include <SFML/Internal.h>
 #include <SFML/CallbackStream.h>
 
+
 ////////////////////////////////////////////////////////////
 sfImage* sfImage_create(unsigned int width, unsigned int height)
 {
@@ -131,6 +133,14 @@ sfBool sfImage_saveToFile(const sfImage* image, const char* filename)
 }
 
 
+////////////////////////////////////////////////////////////
+sfBool sfImage_saveToMemory(const sfImage* image, sfBuffer* output, const char* format)
+{
+    CSFML_CHECK_RETURN(output, sfFalse);
+    CSFML_CALL_RETURN(image, saveToMemory(output->buffer, format), sfFalse);
+}
+
+
 ////////////////////////////////////////////////////////////
 void sfImage_createMaskFromColor(sfImage* image, sfColor colorKey, sfUint8 alpha)
 {
