@@ -150,15 +150,15 @@ sfBool sfRenderWindow_pollEvent(sfRenderWindow* renderWindow, sfEvent* event)
     CSFML_CHECK_RETURN(event,        sfFalse);
 
     // Get the event
-    sf::Event SFMLEvent;
-    sfBool ret = renderWindow->This.pollEvent(SFMLEvent);
+    sf::Event sfmlEvent;
+    sfBool ret = renderWindow->This.pollEvent(sfmlEvent);
 
     // No event, return
     if (!ret)
         return sfFalse;
 
     // Convert the sf::Event event to a sfEvent
-    convertEvent(SFMLEvent, event);
+    convertEvent(sfmlEvent, event);
 
     return sfTrue;
 }
@@ -171,15 +171,15 @@ sfBool sfRenderWindow_waitEvent(sfRenderWindow* renderWindow, sfEvent* event)
     CSFML_CHECK_RETURN(event,        sfFalse);
 
     // Get the event
-    sf::Event SFMLEvent;
-    sfBool ret = renderWindow->This.waitEvent(SFMLEvent);
+    sf::Event sfmlEvent;
+    sfBool ret = renderWindow->This.waitEvent(sfmlEvent);
 
     // Error, return
     if (!ret)
         return sfFalse;
 
     // Convert the sf::Event event to a sfEvent
-    convertEvent(SFMLEvent, event);
+    convertEvent(sfmlEvent, event);
 
     return sfTrue;
 }
@@ -220,6 +220,14 @@ sfVector2u sfRenderWindow_getSize(const sfRenderWindow* renderWindow)
 }
 
 
+////////////////////////////////////////////////////////////
+sfBool sfRenderWindow_isSrgb(const sfRenderWindow* renderWindow)
+{
+    CSFML_CHECK_RETURN(renderWindow, sfFalse);
+    return renderWindow->This.isSrgb();
+}
+
+
 ////////////////////////////////////////////////////////////
 void sfRenderWindow_setSize(sfRenderWindow* renderWindow, sfVector2u size)
 {
@@ -339,7 +347,7 @@ sfWindowHandle sfRenderWindow_getSystemHandle(const sfRenderWindow* renderWindow
 {
     CSFML_CHECK_RETURN(renderWindow, 0);
 
-    return (sfWindowHandle)renderWindow->This.getSystemHandle();
+    return static_cast<sfWindowHandle>(renderWindow->This.getSystemHandle());
 }
 
 
