@@ -28,10 +28,7 @@
 ////////////////////////////////////////////////////////////
 // Define macros to check the validity of CSFML objects in debug run
 ////////////////////////////////////////////////////////////
-#include <stdio.h>
-
-// this macro avoids the C4127 warning on VC++ ("conditional expression is constant")
-#define ASSERT_FALSE (__LINE__ == -1)
+#include <SFML/System/Err.hpp>
 
 #ifndef NDEBUG
 
@@ -40,11 +37,11 @@
         { \
             if (object_ == NULL) \
             { \
-                fprintf(stderr, "SFML warning: trying to use a null " #object_ " object\n"); \
+                sf::err() << "SFML warning: trying to use a null " #object_ " object\n"; \
                 return; \
             } \
         } \
-        while (ASSERT_FALSE)
+        while (0)
 
     #define CSFML_CALL(object_, function_) \
         do \
@@ -55,10 +52,10 @@
             } \
             else \
             { \
-                fprintf(stderr, "SFML warning: trying to use a null " #object_ " object\n"); \
+                sf::err() << "SFML warning: trying to use a null " #object_ " object\n"; \
             } \
         } \
-        while (ASSERT_FALSE)
+        while (0)
 
     #define CSFML_CALL_PTR(object_, function_) \
         do \
@@ -69,21 +66,21 @@
             } \
             else \
             { \
-                fprintf(stderr, "SFML warning: trying to use a null " #object_ " object\n"); \
+                sf::err() << "SFML warning: trying to use a null " #object_ " object\n"; \
             } \
         } \
-        while (ASSERT_FALSE)
+        while (0)
 
     #define CSFML_CHECK_RETURN(object_, default_) \
         do \
         { \
             if (object_ == NULL) \
             { \
-                fprintf(stderr, "SFML warning: trying to use a null " #object_ " object\n"); \
+                sf::err() << "SFML warning: trying to use a null " #object_ " object\n"; \
                 return default_; \
             } \
         } \
-        while (ASSERT_FALSE)
+        while (0)
 
     #define CSFML_CALL_RETURN(object_, function_, default_) \
         if (object_) \
@@ -92,7 +89,7 @@
         } \
         else \
         { \
-            fprintf(stderr, "SFML warning: trying to use a null " #object_ " object\n"); \
+            sf::err() << "SFML warning: trying to use a null " #object_ " object\n"; \
             return default_; \
         }
 
@@ -103,7 +100,7 @@
         } \
         else \
         { \
-            fprintf(stderr, "SFML warning: trying to use a null " #object_ " object\n"); \
+            sf::err() << "SFML warning: trying to use a null " #object_ " object\n"; \
             return default_; \
         }
 
